
package MT::Plugin::Bookmarks;
use strict;
use Data::Dumper;

use vars qw( $VERSION $SCHEMA_VERSION );
$VERSION = '1.0b2';
$SCHEMA_VERSION = '0.91';

use base qw( MT::Plugin );

use MT;

my $plugin = MT::Plugin::Bookmarks->new({
	'name' => 'Bookmarks',
	'author_name' => 'Kevin Shay',
	'author_link' => 'http://www.staggernation.com/mtplugins/',
	'description' => 'Bookmark actions in the Movable Type interface.',
	'version' => $VERSION,
	'schema_version' => $SCHEMA_VERSION,
	'callbacks' => {
		'MT::App::CMS::template_param' => \&header_param,
		'MT::App::CMS::template_output' => \&header_output
	}
});
MT->add_plugin($plugin);

sub init_registry {
	my $component = shift;
	my $reg = {
		'object_types' => {
			'bookmark' => 'MT::Bookmark'
		},
		'applications' => {
			'cms' => {
				'methods' => {
					'bm_add_bookmark' => sub { method_dispatch('add_bookmark', @_) },
					'bm_save_label' => sub { method_dispatch('save_label', @_) },
					'bm_edit_label' => sub { method_dispatch('edit_label', @_) },
					'bm_manage_bookmarks' => sub { method_dispatch('manage_bookmarks', @_) },
				}
			}
		}
	};
	$component->registry($reg);
}

sub header_param {
	my ($cb, $app, $param) = @_;
	require MT::Bookmark;
	require Bookmarks::Util;
	my $menu = {
		'id' => 'bookmarks',
		'label' => 'Bookmarks',
		'allowed' => 1
	};
	my $label = Bookmarks::Util::make_label($app->make_return_args);
	my $rows = [
		{
			'label' => 'Bookmark ' . ($label ? qq{"$label"} : 'This Page'),
			'dialog' => 'bm_add_bookmark',
			'allowed' => 1
		},
		{
			'label' => 'Manage Bookmarks',
			'link' => $app->uri . '?__mode=bm_manage_bookmarks',
			'allowed' => 1
		},
	];
	for my $bookmark (MT::Bookmark->load({ 'author_id' => $app->user->id })) {
		my $row = {
			'label' => $bookmark->label || '...',
			'link' => $app->uri . '?' . $bookmark->args,
			'allowed' => 1
		};
		push(@$rows, $row);
	}
	$menu->{'sub_nav_loop'} = $rows;
	push(@{$param->{'top_nav_loop'}}, $menu);
}

sub header_output {
# hack to prevent menu from being limited to 150px
	my ($cb, $app, $template) = @_;
	my $old = qq{<li id="bookmarks-menu"};
	$old = quotemeta($old);
	my $new = <<'OUTPUT';
<style type="text/css">
#blog-nav-list li#bookmarks-menu ul {
width:auto;
}
</style>
OUTPUT
	$$template =~ s/($old)/$new$1/;
}

sub method_dispatch {
	my $meth = shift;
	require Bookmarks::App;
	Bookmarks::App->$meth($plugin, @_);
}

1;
