
package Bookmarks::App;
use strict;
use Data::Dumper;

sub add_bookmark {
	my $class = shift;
	my ($plugin, $app) = @_;
	require Bookmarks::Util;
	my $args = $app->param('return_args');
	my $label = Bookmarks::Util::make_label($app->param('return_args'));
	require MT::Bookmark;
	if (MT::Bookmark->load({ 'author_id' => $app->user->id, 'args' => $args })) {
		return $app->error('You already have this page bookmarked.');
	}
	my $bookmark = MT::Bookmark->new;
	$bookmark->author_id($app->user->id);
	$bookmark->args($args);
	$bookmark->label($label || 'Unknown Action');
	$bookmark->save || die $bookmark->errstr;
	my %param = (
		'added' => 1,
		'label' => $label,
		'return_args' => $args,
		'id' => $bookmark->id
	);
	return $app->build_page($plugin->load_tmpl('dialog/edit_label.tmpl'), \%param);
}

sub edit_label {
	my $class = shift;
	my ($plugin, $app) = @_;
	require MT::Bookmark;
	return $app->error('No bookmark ID passed') unless $app->param('id');
	(my $bookmark = MT::Bookmark->load($app->param('id')))
		|| return $app->error('Bookmark ' . $app->param('id') . ' not found');
	my %param = (
		'label' => $bookmark->label,
		'return_args' => $bookmark->args,
		'id' => $bookmark->id
	);
	return $app->build_page($plugin->load_tmpl('dialog/edit_label.tmpl'), \%param);
}

sub save_label {
	my $class = shift;
	my ($plugin, $app) = @_;
	if ($app->param('no_save')) {
			# user clicked Done button from adding; need to refresh
		return $app->redirect($app->uri . '?' . $app->param('return_args'));
	}
	require MT::Bookmark;
	return $app->error('No bookmark ID passed') unless $app->param('id');
	(my $bookmark = MT::Bookmark->load($app->param('id')))
		|| return $app->error('Bookmark ' . $app->param('id') . ' not found');
	$bookmark->label($app->param('label'));
	$bookmark->save || die $bookmark->errstr;
	return $app->redirect($app->uri . '?' . $app->param('return_args'));
}

sub manage_bookmarks {
	my $class = shift;
	my ($plugin, $app) = @_;
	my $hasher = sub {
		my ($obj, $row) = @_;
		for my $col (qw( id label args )) {
			$row->{$col} = $obj->$col;
		}
		$row->{'label'} ||= '...';
	};
	return $app->listing({
		'type' => 'bookmark',
		'template' => $plugin->load_tmpl('list_bookmark.tmpl'),
		'terms' => {
			'author_id' => $app->user->id
		},
		'args' => {
			'sort_order' => 'sort',
			'direction' => 'ascend'
		},
		'hasher' => $hasher,
		'param' => {
			'author_id' => $app->user->id
		},
		'params' => {
			'saved_deleted' => $app->param('saved_deleted') ? 1 : 0
		}
	});
}

1;
