
package Bookmarks::Util;
use strict;
use Data::Dumper;

sub make_label {
	my ($return_args) = @_;
	my ($app) = @_;
	my %param = ();
	my $args = {};
	$return_args ||= '';
	for my $arg (split(/[&;]/, $return_args)) {
		my ($key, $value) = split(/=/, $arg);
		$args->{$key} = $value;
	}
	my $label = '';
	if (!$args->{'__mode'}) {
		$label = 'Dashboard';
	} elsif (!$args->{'blog_id'} && ($args->{'__mode'} eq 'view')) {
		$label = $args->{'id'} ? 'Edit ' : 'Create New ';
		if ($args->{'type'} eq 'blog') {
			$label .= 'Blog';
		} elsif ($args->{'_type'} eq 'author') {
			$label .= 'User';
		}
	} elsif (!$args->{'blog_id'} && (my $v_n = v_n($args))) {
		$label = "$v_n: System-Wide";
	} elsif (!$args->{'blog_id'}) {
		my %descs = (
			'cfg_system' => 'General Settings: System-Wide',
			'cfg_system_feedback' => 'Feedback Settings: System-Wide',
			'cfg_plugins' => 'Plugin Settings: System-Wide',
			'view_log' => 'Activity Log',
			'tools' => 'Tools',
			'system_check' => 'System Information',
			'start_backup' => 'Backup',
			'start_restore' => 'Restore'
		);
		$label = $descs{$args->{'__mode'}};
	} else {
		my $v_n = v_n($args);
		require MT::Blog;
		my $blog = MT::Blog->load($args->{'blog_id'});
		$label .= $blog->name . ": $v_n";
	}
	return $label;
}

sub v_n {
	my ($args) = @_;
	my $label = '';
	if ($args->{'__mode'} eq 'dashboard') {
		$label = 'Dashboard';
	} elsif ($args->{'__mode'} eq 'view') {
		if ($args->{'id'}) {
			$label = 'Edit '. ucfirst($args->{'_type'});
			$label .= " $args->{'id'}";
		} else {
			$label = 'New ' . ucfirst($args->{'_type'});
		}
	} elsif ($args->{'__mode'} =~ /^list/) {
		my $type;
		if ($args->{'__mode'} ne 'list') {
			$args->{'__mode'} =~ /^list_(.+)/;
			$type = $1;
		} else {
			$type = $args->{'_type'};
		}
		$type = 'folders' if ($args->{'_type'} && ($args->{'_type'} eq 'folder'));
		my %map = (
			'pings' => 'TrackBacks',
			'assets' => 'Files',
			'cat' => 'Categories',
			'widget' => 'Widgets',
			'tag' => 'Tags',
			'authors' => 'Users',
			'entry' => 'Entries'
		);
		if ($type eq 'template') {
			my $filter = $args->{'filter_key'} || 'index_templates';
			$filter =~ s/_templates$//;
			my %fmap = (
				'module' => 'Template Modules',
				'widget' => 'Widgets'
			);
			$map{'template'} = $fmap{$filter} || ucfirst($filter) . ' Templates';
		}
		$label .= $map{$type} || ucfirst($type);
	} elsif ($args->{'__mode'} =~ /^cfg/) {
		$args->{'__mode'} =~ /^cfg_(.+)/;
		my $type = $1;
		my %map = (
			'prefs' => 'General',
			'system' => 'General',
			'system_feedback' => 'Feedback',
			'plugins' => 'Plugin',
			'archives' => 'Publishing',
			'entry' => 'Entries',
			'trackbacks' => 'TrackBacks',
			'web_services' => 'Web Services'			
		);
		$label = $map{$type} || ucfirst($type);
		$label .= ' Settings';
	}
	return $label;
}

1;